systemtools.AttributeDetail
===========================

.. abjad-lineage:: abjad.tools.systemtools.AttributeDetail.AttributeDetail

.. autoclass:: abjad.tools.systemtools.AttributeDetail.AttributeDetail

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.AttributeDetail.AttributeDetail.command
      ~abjad.tools.systemtools.AttributeDetail.AttributeDetail.display_string
      ~abjad.tools.systemtools.AttributeDetail.AttributeDetail.editor
      ~abjad.tools.systemtools.AttributeDetail.AttributeDetail.is_keyword
      ~abjad.tools.systemtools.AttributeDetail.AttributeDetail.name
      ~abjad.tools.systemtools.AttributeDetail.AttributeDetail.__eq__
      ~abjad.tools.systemtools.AttributeDetail.AttributeDetail.__format__
      ~abjad.tools.systemtools.AttributeDetail.AttributeDetail.__hash__
      ~abjad.tools.systemtools.AttributeDetail.AttributeDetail.__ne__
      ~abjad.tools.systemtools.AttributeDetail.AttributeDetail.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.systemtools.AttributeDetail.AttributeDetail.command
   :noindex:

.. autoattribute:: abjad.tools.systemtools.AttributeDetail.AttributeDetail.display_string
   :noindex:

.. autoattribute:: abjad.tools.systemtools.AttributeDetail.AttributeDetail.editor
   :noindex:

.. autoattribute:: abjad.tools.systemtools.AttributeDetail.AttributeDetail.is_keyword
   :noindex:

.. autoattribute:: abjad.tools.systemtools.AttributeDetail.AttributeDetail.name
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.systemtools.AttributeDetail.AttributeDetail.__eq__
   :noindex:

.. automethod:: abjad.tools.systemtools.AttributeDetail.AttributeDetail.__format__
   :noindex:

.. automethod:: abjad.tools.systemtools.AttributeDetail.AttributeDetail.__hash__
   :noindex:

.. automethod:: abjad.tools.systemtools.AttributeDetail.AttributeDetail.__ne__
   :noindex:

.. automethod:: abjad.tools.systemtools.AttributeDetail.AttributeDetail.__repr__
   :noindex:
